==> haskell-math-functions-0.3.1.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: math-functions
version: 0.3.1.0
id: math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
key: math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
license: BSD-2-Clause
maintainer: Alexey Khudyakov <alexey.skladnoy@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>,
        Alexey Khudyakov <alexey.skladnoy@gmail.com>
homepage: https://github.com/bos/math-functions
synopsis: Collection of tools for numeric computations
description:
    This library contain collection of various utilities for numerical
    computing. So far there'\''re special mathematical functions,
    compensated summation algorithm, summation of series, root finding
    for real functions, polynomial summation and Chebyshev
    polynomials.
category: Math, Numeric
abi: e707d18d2b008cfa36d192528cbbf36f
exposed: True
exposed-modules:
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.Series Numeric.SpecFunctions Numeric.SpecFunctions.Extra
    Numeric.Sum
hidden-modules: Numeric.SpecFunctions.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/math-functions-0.3.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/math-functions-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/math-functions-0.3.1.0
hs-libraries: HSmath-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
depends:
    base-4.12.0.0 data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    deepseq-1.4.4.0 primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-th-unbox-0.2.1.6-LZLuOhl72IF7NW8IrRJm9b
haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
haddock-html: /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-math-functions-0.3.2.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: math-functions
version: 0.3.2.1
id: math-functions-0.3.2.1-KHpmsRMeLk726whakxkYZR
key: math-functions-0.3.2.1-KHpmsRMeLk726whakxkYZR
license: BSD-2-Clause
maintainer: Alexey Khudyakov <alexey.skladnoy@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>,
        Alexey Khudyakov <alexey.skladnoy@gmail.com>
homepage: https://github.com/bos/math-functions
synopsis: Collection of tools for numeric computations
description:
    This library contain collection of various utilities for numerical
    computing. So far there'\''re special mathematical functions,
    compensated summation algorithm, summation of series, root finding
    for real functions, polynomial summation and Chebyshev
    polynomials.
category: Math, Numeric
abi: 8939fb82574c34855895bcb7759654d7
exposed: True
exposed-modules:
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.Series Numeric.SpecFunctions Numeric.SpecFunctions.Extra
    Numeric.Sum
hidden-modules: Numeric.SpecFunctions.Internal
                Numeric.SpecFunctions.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/math-functions-0.3.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/math-functions-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/math-functions-0.3.2.1
hs-libraries: HSmath-functions-0.3.2.1-KHpmsRMeLk726whakxkYZR
depends:
    base-4.12.0.0 data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    deepseq-1.4.4.0 primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-th-unbox-0.2.1.6-LZLuOhl72IF7NW8IrRJm9b
haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
haddock-html: /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
